package com.usky.dxtop.controller.web.business;


import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.model.Dish;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.service.DishService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.vo.DishRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Optional;

/**
 * 消费模块
 * @author yq
 * @since 2021-09-09
 */
@RestController
@RequestMapping("/dxtop/dish")
public class DishController {



    @Autowired
    private DishService dishService;

    @Autowired
    private StaffService staffService;

    /**
     * 记录查询
     * @param dishRequest
     * @return
     */
    @PostMapping("page")
    public ApiResult<CommonPage<Dish>> page(@Validated @RequestBody DishRequest dishRequest){
        return ApiResult.success(dishService.page(dishRequest));
    }

    /**
     * 消费详情
     * @param seq
     * @return
     */
    @GetMapping(value = "/{seq}")
    public ApiResult<Dish> one(@PathVariable Long seq){
        return ApiResult.success(dishService.one(seq));
    }



    /**
     * 消费汇总统计
     * @return
     */
    @GetMapping(value = "/collect")
    public ApiResult collect(){
        return ApiResult.success(dishService.collect());
    }

    /**
     * 批量修改消息状态
     * @return
     */
    @PutMapping
    public ApiResult<Boolean> update(@RequestParam String userId) {
        Staff staff = staffService.one(userId, null, null);
        Optional.ofNullable(staff).orElseThrow(() -> new CustomException("用户信息不存在"));
        LambdaUpdateWrapper<Dish> updateWrapper = Wrappers.lambdaUpdate();
        updateWrapper.set(Dish::getMessageFlag,true)
                .eq(Dish::getCard,staff.getCardId());
        return ApiResult.success(dishService.update(updateWrapper));
    }

}

