package com.usky.dxtop.controller.web.business;


import com.usky.dxtop.common.annotation.RepeatSubmit;
import com.usky.dxtop.common.constant.UserConstants;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.SecurityUtils;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.QrCode;
import com.usky.dxtop.service.QrCodeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 *  二维码管理
 *
 * @author yq
 * @since 2021-08-26
 */
@RestController
@RequestMapping("/dxtop/qrCode")
public class QrCodeController extends BaseController {


    @Autowired
    private QrCodeService qrCodeService;

    /**
     * 新增记录
     * @param qrCode
     * @return
     */
    @RepeatSubmit
    @PostMapping
    public ApiResult add(@RequestBody QrCode qrCode){
        if (UserConstants.NOT_UNIQUE.equals(qrCodeService.checkNameUnique(qrCode)))
        {
            throw new CustomException("新增二维码信息'" + qrCode.getName() + "'失败，二维码信息已存在");
        }
        return toAjax(qrCodeService.add(qrCode));

    }

    /**
     * 修改记录
     */
    @PutMapping
    public ApiResult edit(@RequestBody QrCode qrCode)
    {
        if (UserConstants.NOT_UNIQUE.equals(qrCodeService.checkNameUnique(qrCode)))
        {
            throw new CustomException("修改二维码信息'" + qrCode.getName() + "'失败，二维码信息已存在");
        }
        qrCode.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(qrCodeService.updateById(qrCode));
    }

    /**
     * 记录查询
     * @param current 页数
     * @param size 条数
     * @param name 名称
     * @return
     */
    @GetMapping("/list")
    public ApiResult<CommonPage<QrCode>> list(@RequestParam Integer current,
                                      @RequestParam Integer size,
                                      @RequestParam(required = false) String name)
    {
        return ApiResult.success(qrCodeService.list(current, size, name));
    }


    /**
     * 删除记录
     */
    @DeleteMapping("/{id}")
    public ApiResult remove(@PathVariable("id") Long id)
    {
        return toAjax(qrCodeService.remove(id));
    }
}

