package com.usky.dxtop.controller.web.business;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.dxtop.common.annotation.RepeatSubmit;
import com.usky.dxtop.common.constant.UserConstants;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.SecurityUtils;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.TopChannel;
import com.usky.dxtop.service.TopChannelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 充值渠道
 *
 * @author yq
 * @since 2021-08-26
 */
@RestController
@RequestMapping("/dxtop/topChannel")
public class TopChannelController extends BaseController {


    @Autowired
    private TopChannelService topChannelService;

    /**
     * 新增记录
     * @param topChannel
     * @return
     */
    @RepeatSubmit
    @PostMapping
    public ApiResult add(@Validated @RequestBody TopChannel topChannel){
        if (UserConstants.NOT_UNIQUE.equals(topChannelService.checkNameUnique(topChannel)))
        {
            throw new CustomException("新增渠道信息'" + topChannel.getName() + "'失败，渠道信息已存在");
        }
        topChannel.setCreateBy(SecurityUtils.getUsername());
        return toAjax(topChannelService.save(topChannel));

    }

    /**
     * 修改记录
     */
    @PutMapping
    public ApiResult edit(@Validated @RequestBody TopChannel topChannel)
    {
        if (UserConstants.NOT_UNIQUE.equals(topChannelService.checkNameUnique(topChannel)))
        {
            throw new CustomException("修改渠道信息'" + topChannel.getName() + "'失败，渠道信息已存在");
        }
        topChannel.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(topChannelService.updateById(topChannel));
    }

    /**
     * 记录查询
     * @param current 页数
     * @param size 条数
     * @param name 名称
     * @return
     */
    @GetMapping("/page")
    public ApiResult<CommonPage<TopChannel>> page(@RequestParam Integer current,
                                      @RequestParam Integer size,
                                      @RequestParam(required = false) String name)
    {
        return ApiResult.success(topChannelService.list(current, size, name));
    }

    /**
     * 全部数据
     * @param name
     * @return
     */
    @GetMapping("/list")
    public ApiResult<List<TopChannel>> list(@RequestParam(required = false) String name)
    {
        LambdaQueryWrapper<TopChannel> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(StringUtils.isNotBlank(name),TopChannel::getName,name);
        return ApiResult.success(topChannelService.list(queryWrapper));
    }


    /**
     * 删除记录
     */
    @DeleteMapping("/{id}")
    public ApiResult remove(@PathVariable("id") Long id)
    {
        return toAjax(topChannelService.remove(id));
    }

    /**
     * 渠道订单金额
     * @return
     */
    @GetMapping("/channelOrderMoney")
    public ApiResult channelOrderMoney(){
        return ApiResult.success(topChannelService.channelOrderMoney());
    }
}

