package com.usky.dxtop.controller.web.business;


import com.usky.dxtop.common.annotation.RepeatSubmit;
import com.usky.dxtop.common.constant.UserConstants;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.SecurityUtils;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.TopRadio;
import com.usky.dxtop.service.TopRadioService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 充值到账比例
 *
 * @author yq
 * @since 2021-08-26
 */
@RestController
@RequestMapping("/dxtop/topRadio")
public class TopRadioController extends BaseController {

    @Autowired
    private TopRadioService topRadioService;

    /**
     * 新增记录
     * @param topRadio
     * @return
     */
    @RepeatSubmit
    @PostMapping
    public ApiResult add(@Validated @RequestBody TopRadio topRadio){
        if (UserConstants.NOT_UNIQUE.equals(topRadioService.checkIdentityUnique(topRadio)))
        {
            throw new CustomException("新增身份信息'" + topRadio.getIdentity() + "'失败，身份信息已存在");
        }
        topRadio.setCreateBy(SecurityUtils.getUsername());
        return toAjax(topRadioService.save(topRadio));

    }

    /**
     * 修改记录
     */
    @PutMapping
    public ApiResult edit(@Validated @RequestBody TopRadio topRadio)
    {
        if (UserConstants.NOT_UNIQUE.equals(topRadioService.checkIdentityUnique(topRadio)))
        {
            throw new CustomException("修改身份信息'" + topRadio.getIdentity() + "'失败，身份信息已存在");
        }
        topRadio.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(topRadioService.updateById(topRadio));
    }

    /**
     * 记录查询
     * @param current 页数
     * @param size 条数
     * @param identity 身份信息
     * @return
     */
    @GetMapping("/list")
    public ApiResult<CommonPage<TopRadio>> list(@RequestParam Integer current,
                                      @RequestParam Integer size,
                                      @RequestParam(required = false) String identity)
    {
        return ApiResult.success(topRadioService.list(current, size, identity));
    }


    /**
     * 删除记录
     */
    @DeleteMapping("/{id}")
    public ApiResult remove(@PathVariable("id") Long id)
    {
        TopRadio topRadio = new TopRadio();
        topRadio.setId(id);
        topRadio.setDelFlag(true);
        return toAjax(topRadioService.updateById(topRadio));
    }

    /**
     * 获取全部
     * @return
     */
    @GetMapping("/all")
    public ApiResult<List<TopRadio>> all(){
        return ApiResult.success(topRadioService.list());
    }

}

