package com.usky.dxtop.controller.web.monitor;

import com.usky.dxtop.common.annotation.Log;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.TableDataInfo;
import com.usky.dxtop.common.enums.BusinessType;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.SysOperLog;
import com.usky.dxtop.service.ISysOperLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 操作日志记录
 * 
 * @author yq
 */
@RestController
@RequestMapping("/monitor/operlog")
public class SysOperlogController extends BaseController
{
    @Autowired
    private ISysOperLogService operLogService;

    @PreAuthorize("@ss.hasPermi('monitor:operlog:list')")
    @GetMapping("/list")
    public ApiResult<TableDataInfo> list(SysOperLog operLog)
    {
        startPage();
        List<SysOperLog> list = operLogService.selectOperLogList(operLog);
        return ApiResult.success(getDataTable(list));
    }


    @Log(title = "操作日志", businessType = BusinessType.DELETE)
    @PreAuthorize("@ss.hasPermi('monitor:operlog:remove')")
    @DeleteMapping("/{operIds}")
    public ApiResult remove(@PathVariable Long[] operIds)
    {
        return toAjax(operLogService.deleteOperLogByIds(operIds));
    }

    @Log(title = "操作日志", businessType = BusinessType.CLEAN)
    @PreAuthorize("@ss.hasPermi('monitor:operlog:remove')")
    @DeleteMapping("/clean")
    public ApiResult clean()
    {
        operLogService.cleanOperLog();
        return ApiResult.success();
    }
}
