package com.usky.dxtop.controller.web.system;


import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.model.SysFile;
import com.usky.dxtop.service.SysFileService;
import com.usky.dxtop.service.vo.SysFileQueryRequest;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * 系统文件
 * @author yq
 * @since 2021-10-09
 */
@RestController
@RequestMapping("/sysFile")
public class SysFileController {

    @Autowired
    private SysFileService sysFileService;


    /**
     * 上传文件
     * @param multipartFiles
     * @param urls
     * @param batchNo
     * @param businessType
     * @param uploadType
     * @param expireAt
     * @return
     */
    @PostMapping
    public ApiResult<List<SysFile>> uploadFile(
            @RequestParam(value = "files",required = false) MultipartFile[] multipartFiles,
            @RequestParam(value = "urls[]",required = false) String[] urls,
            @RequestParam("batchNo") String batchNo,
            @RequestParam("businessType") String businessType,
            @RequestParam(name = "uploadType", required = false) String uploadType,
            @RequestParam(name = "expireAt", required = false) Date expireAt) {
        com.usky.dxtop.model.SysFile sysFile = new com.usky.dxtop.model.SysFile();
        sysFile.setUploadType(uploadType);
        sysFile.setBusinessType(businessType);
        sysFile.setBatchNo(batchNo);
        sysFile.setExpriceAt(expireAt);
        sysFile.setFiles(Arrays.asList(multipartFiles));
        sysFile.setUrls(null != urls?Arrays.asList(urls):null);
        return ApiResult.success(sysFileService.addFile(sysFile));
    }

    /**
     * 获取文件
     * @param sysFileQueryRequest
     * @return
     */
    @PostMapping("getFile")
    public ApiResult<List<SysFile>> getFile(@RequestBody SysFileQueryRequest sysFileQueryRequest) {
        return ApiResult.success(sysFileService.getFile(sysFileQueryRequest));
    }

    /**
     * 分页
     * @param sysFileQueryRequest
     * @return
     */
    @PostMapping("page")
    public ApiResult<CommonPage<SysFile>> page(@RequestBody SysFileQueryRequest sysFileQueryRequest) {
        return ApiResult.success(sysFileService.page(sysFileQueryRequest));
    }


    /**
     * 生成批次编号
     * @return
     */
    @GetMapping("/generateBatchNo")
    public ApiResult<String> generateBatchNo() {
        return ApiResult.success(sysFileService.generateBatchNo());
    }

    /**
     * 文件生效
     * @param batchNo
     * @param ids
     * @return
     */
    @PostMapping("/active")
    public ApiResult active(@RequestParam("batchNo") String batchNo,
                            @RequestParam(value = "ids[]",required = false) String[] ids){
        return ApiResult.success(sysFileService.active(batchNo,Arrays.asList(ids)));
    }
}

