package com.usky.dxtop.controller.web.system;

import com.usky.dxtop.common.constant.Constants;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.domain.model.LoginBody;
import com.usky.dxtop.common.core.domain.model.LoginUser;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.ServletUtils;
import com.usky.dxtop.framework.web.service.SysLoginService;
import com.usky.dxtop.framework.web.service.SysPermissionService;
import com.usky.dxtop.framework.web.service.TokenService;
import com.usky.dxtop.model.SysMenu;
import com.usky.dxtop.model.SysUser;
import com.usky.dxtop.service.util.CenterDecryptUtil;
import com.usky.dxtop.service.ISysMenuService;
import com.usky.dxtop.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;


/**
 * 登录验证
 * 
 * @author yq
 */
@RestController
public class SysLoginController
{
    @Autowired
    private SysLoginService loginService;

    @Autowired
    private ISysMenuService menuService;

    @Autowired
    private SysPermissionService permissionService;

    @Autowired
    private TokenService tokenService;
    @Autowired
    private ISysUserService sysUserService;

    /**
     * 登录方法
     * 
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public ApiResult login(@RequestBody LoginBody loginBody)
    {
        Map<String,Object> map = new HashMap<>();
        // 生成令牌
        String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(),
                loginBody.getUuid(),null);
        map.put(Constants.TOKEN, token);
        return ApiResult.success(map);
    }

    /**
     * 单点登录
     * @param loginBody
     * @return
     */
    @PostMapping("/loginByCenter")
    public ApiResult getToken(@RequestBody LoginBody loginBody)
    {
        try {
            loginBody.setUsername(CenterDecryptUtil.decryptByPrivateKey(CenterDecryptUtil.KEY, loginBody.getUsername()));
            loginBody.setPassword(CenterDecryptUtil.decryptByPrivateKey(CenterDecryptUtil.KEY, loginBody.getPassword()));
        }catch (Exception e){
            throw new CustomException("验证失败");
        }
        Map<String,Object> map = new HashMap<>();
        // 生成令牌
        String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), null,
                null,false);
        map.put(Constants.TOKEN, token);
        return ApiResult.success(map);
    }

    /**
     * 获取用户信息
     * 
     * @return 用户信息
     */
    @GetMapping("getInfo")
    public ApiResult getInfo()
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        SysUser user = loginUser.getUser();
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(user);
        Map<String,Object> map = new HashMap<>();
        map.put("user", user);
        map.put("roles", roles);
        map.put("permissions", permissions);
        return ApiResult.success(map);
    }

    /**
     * 获取路由信息
     * 
     * @return 路由信息
     */
    @GetMapping("getRouters")
    public ApiResult getRouters()
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        // 用户信息
        SysUser user = loginUser.getUser();
        List<SysMenu> menus = menuService.selectMenuTreeByUserId(user.getUserId());
        return ApiResult.success(menuService.buildMenus(menus));
    }
}
