package com.usky.dxtop.service;


import com.baomidou.mybatisplus.extension.service.IService;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.model.Company;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.model.SysFile;
import com.usky.dxtop.service.vo.StaffRequest;
import com.usky.dxtop.service.vo.SysFileQueryRequest;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * <p>
 *  服务类
 * </p>
 *
 * @author yq
 * @since 2021-10-09
 */
public interface SysFileService extends IService<SysFile> {

    /**
     * 添加文件到sysfile
     * 可以同时长传多个文件. 但相比V2,不能够指定key. key随机生成.
     * @param sysFile
     * @return
     */
    List<SysFile> addFile(SysFile sysFile);

    /**
     * 添加multipart file
     * @param m
     * @param sysFile
     * @return
     */
    SysFile uploadMultipartFile(MultipartFile m, SysFile sysFile);

    /**
     * 添加链接
     * @param url
     * @param sysFile
     * @return
     */
    SysFile addExternalLink(String url, SysFile sysFile);


    /**
     * 生成新的batchNo
     * @return
     */
    String generateBatchNo();

    /**
     * 确认文件生效
     * @param batchNo
     * @param fileIds
     * @return
     */
    Boolean active(String batchNo, List<String> fileIds);

    /**
     * 获取文件
     * @param sysFileRequest
     * @return
     */
    List<SysFile> getFile(SysFileQueryRequest sysFileRequest);


    CommonPage<SysFile> page(SysFileQueryRequest sysFileRequest);


    /**
     * 批量删除文件(更新文件删除状态)
     *
     * @param sysFiles
     * @return
     */
    Integer deleteFiles(List<SysFile> sysFiles);

    /**
     * 通过batchNo删除
     *
     * @param batchNo
     * @return
     */
    Integer removeByBatchNo(String batchNo);


    /**
     * 清理垃圾文件.
     *
     * @param fileList
     * @return
     */
    Integer clearFiles(List<SysFile> fileList);
}
