package com.usky.dxtop.service.api;


import com.usky.dxtop.common.utils.DateUtils;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.common.utils.sign.Md5Utils;
import com.usky.dxtop.common.utils.uuid.UUID;
import lombok.Data;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

import java.util.Map;
import java.util.TreeMap;

/**
 * @author yq
 * @date 2021/8/23 14:50
 */
@Data
@Component
@ConfigurationProperties(prefix = "toppay")
public class TopApiConfiger {

    /**
     * 版本
     */
    @Value("${toppay.version}")
    public String version;
    /**
     * 扫码支付
     */
    @Value("${toppay.scanPayUrl}")
    public String scanPayUrl;
    /**
     * 交易查询
     */
    @Value("${toppay.dealSelectUrl}")
    public  String dealSelectUrl;

    /**
     * 统一支付
     */
    @Value("${toppay.unifyUrl}")
    public String unifyUrl;

    /**
     * 商户编号
     */
    @Value("${toppay.merchantNo}")
    public String merchantNo;

    /**
     * 密钥
     */
    @Value("${toppay.secret}")
    public String secret;

    /**
     * 回调url
     */
    @Value("${toppay.notifyUrl}")
    public String notifyUrl;

    /**
     * 微信appid
     */
    @Value("${toppay.wxAppId}")
    public String wxAppId;

    /**
     * 微信密钥
     */
    @Value("${toppay.wxAppSecret}")
    public String wxAppSecret;

    /**
     * 拼接扫码支付参数
     * @return
     */
    public TreeMap<String, String> generateScanPayApiParam(String merchantOrderNo, Integer amount, String note,
                                                                  String storeNo, String backUrl, String orderNumber,
                                                                  String validTime, String remark, String goods){
        TreeMap<String, String> tMap = new TreeMap<>();
        tMap.put("version",version);
        tMap.put("payTime",DateUtils.dateTimeNow());
        tMap.put("merchantNo",merchantNo);
        tMap.put("merchantOrderNo",merchantOrderNo);
        tMap.put("amount",amount.toString());
        tMap.put("note",note);
        tMap.put("storeNo",storeNo);
        tMap.put("backUrl",backUrl);
        tMap.put("orderNumber",orderNumber);
        tMap.put("validTime",validTime);
        tMap.put("remark",remark);
        tMap.put("notifyUrl",notifyUrl);
        tMap.put("goods",goods);
        return tMap;
    }

    /**
     * 交易查询参数
     * @param merchantOrderNo
     * @param storeNo
     * @param trxid
     * @param groupNo
     * @return
     */
    public  TreeMap<String, String> generateDealSelectParam(String merchantOrderNo,String storeNo,String trxid,String groupNo){
        TreeMap<String, String> tMap = new TreeMap<>();
        tMap.put("version",version);
        tMap.put("merchantNo",merchantNo);
        tMap.put("merchantOrderNo",merchantOrderNo);
        tMap.put("storeNo",storeNo);
        tMap.put("trxid",trxid);
        tMap.put("groupNo",groupNo);
        return tMap;
    }

    /**
     * 退单url
     * @param amount
     * @param orderNo
     * @param oriMerchantOrderNo
     * @param trxid
     * @param refundType
     * @param remark
     * @param groupNo
     * @return
     */
    public TreeMap<String, String> generateReturnDealParam(Integer amount,String orderNo,String oriMerchantOrderNo,
                                                                  String trxid,String refundType,String remark,String groupNo){
        TreeMap<String, String> tMap = new TreeMap<>();
        tMap.put("version",version);
        tMap.put("merchantNo",merchantNo);
        tMap.put("amount",amount.toString());
        tMap.put("orderNo",orderNo);
        tMap.put("oriMerchantOrderNo",oriMerchantOrderNo);
        tMap.put("trxid",trxid);
        tMap.put("merchantOrderNo",String.format("RETURN%s", getOrderNumber()));
        tMap.put("refundType",refundType);
        tMap.put("remark",remark);
        tMap.put("groupNo",groupNo);
        return tMap;
    }


    /**
     * 统一支付
     * @param amount
     * @param notifyUrl
     * @param backUrl
     * @param note
     * @param orderName
     * @param acct
     * @param payType
     * @param validTime
     * @param subAppid
     * @param remark
     * @param asinfo
     * @param groupNo
     * @param consumerIp
     * @return
     */
    public TreeMap<String, String> generateUnifyParam(String merchantOrderNo,Integer amount,String notifyUrl,
                                                             String backUrl,String note,String orderName,String acct,
                                                             String payType,String validTime,String subAppid,
                                                             String remark,String asinfo,String groupNo,
                                                             String consumerIp){
        TreeMap<String, String> tMap = new TreeMap<>();
        tMap.put("version",version);
        tMap.put("merchantNo",merchantNo);
        tMap.put("merchantOrderNo",merchantOrderNo);
        tMap.put("amount",amount.toString());
        tMap.put("notifyUrl",notifyUrl);
        tMap.put("backUrl",backUrl);
        tMap.put("note",note);
        tMap.put("orderName",orderName);
        tMap.put("acct",acct);
        tMap.put("payType",payType);
        tMap.put("validTime",validTime);
        tMap.put("subAppid",subAppid);
        tMap.put("remark",remark);
        tMap.put("asinfo",asinfo);
        tMap.put("groupNo",groupNo);
        tMap.put("consumerIp",consumerIp);
        return tMap;
    }


    public String generateParam(TreeMap<String, String> params){
        return String.format("%s&sign=%s",
                this.joinParam(params),
                this.signData(params));
    }

    public String joinParam(TreeMap<String, String> params){
        StringBuilder buf = new StringBuilder();
        for (Map.Entry<String, String> entry : params.entrySet()) {
            if (!StringUtils.isBlank(entry.getValue()) && !"sign".equals(entry.getKey())) {
                buf.append(entry.getKey()).append("=").append(entry.getValue()).append("&");
            }
        }
        String changeBuf = buf.toString();
        return changeBuf.substring(0, changeBuf.length() - 1);
    }



    /**
     * 参数加签
     * 参数加签规则，key+value拼接(value为空时，key value不参与拼接)，以key首字母ascii码排序，最后拼接上secret串再进行MD5加密，得到的MD5密钥字母转大写，例：amount1merchantNo1210500001030341dff192f644b5892338f0d964a6b2
     * @param treeMap
     * @return
     */
    public String signData(Map<String, String> treeMap) {
        StringBuilder buf = new StringBuilder();
        for (Map.Entry<String, String> entry : treeMap.entrySet()) {
            if (!StringUtils.isBlank(entry.getValue()) && !"sign".equals(entry.getKey())) {
                buf.append(entry.getKey()).append(entry.getValue());
            }
        }
        buf.append(secret);
        return Md5Utils.hash(buf.toString()).toUpperCase();
    }

    /**
     * 获取订单编号
     * @return
     */
    public static String getOrderNumber(){
        return UUID.randomUUID().toString(true);
    }
}
