package com.usky.dxtop.service.config.rabbitmq;

import com.usky.dxtop.service.emun.RabbitmqBeenCode;
import org.springframework.amqp.core.Binding;
import org.springframework.amqp.core.BindingBuilder;
import org.springframework.amqp.core.DirectExchange;
import org.springframework.amqp.core.Queue;
import org.springframework.amqp.rabbit.connection.ConnectionFactory;
import org.springframework.amqp.rabbit.core.RabbitAdmin;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.BeanFactoryAware;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.support.DefaultListableBeanFactory;
import org.springframework.boot.autoconfigure.amqp.SimpleRabbitListenerContainerFactoryConfigurer;
import org.springframework.stereotype.Component;

/**
 * @author yq
 * @date 2022/6/9 10:56
 */
@Component
public class RabbitmqFactoryAware implements BeanFactoryAware {

    @Autowired
    private RabbitmqConfig rabbitmqConfig;

    @Autowired
    private SimpleRabbitListenerContainerFactoryConfigurer simpleRabbitListenerContainerFactoryConfigurer;
    @Override
    public void setBeanFactory(BeanFactory beanFactory) throws BeansException {
        DefaultListableBeanFactory listableBeanFactory = (DefaultListableBeanFactory)beanFactory;
        for (RabbitmqBeenCode rabbitmqBeenCode:RabbitmqBeenCode.values()) {
            //创建连接工厂
            ConnectionFactory connectionFactory = rabbitmqConfig.connectionFactory(rabbitmqBeenCode.getName());
            registerSingleton(listableBeanFactory,
                    rabbitmqBeenCode.getModelName() + RabbitmqConfig.CONNECTION,
                    connectionFactory);
            //创建Template
            registerSingleton(listableBeanFactory,
                    rabbitmqBeenCode.getModelName() + RabbitmqConfig.TEMPLATE,
                    rabbitmqConfig.rabbitTemplate(connectionFactory));
            //创建listenerFactory
            registerSingleton(listableBeanFactory,
                    rabbitmqBeenCode.getModelName() + RabbitmqConfig.LISTENER,
                    rabbitmqConfig.listenerFactory(simpleRabbitListenerContainerFactoryConfigurer,connectionFactory));

            //创建admin
            RabbitAdmin rabbitAdmin = new RabbitAdmin(connectionFactory);
            rabbitAdmin.setAutoStartup(true);
            registerSingleton(listableBeanFactory,
                    rabbitmqBeenCode.getModelName() + RabbitmqConfig.ADMIN,
                    rabbitAdmin);

            //创建exchange
            DirectExchange exchange = rabbitmqConfig.exchange(rabbitmqBeenCode.getName(), rabbitAdmin);
            registerSingleton(listableBeanFactory,
                    rabbitmqBeenCode.getModelName() + RabbitmqConfig.EXCHANGE,
                    exchange);

            //创建queue
            Queue queue = rabbitmqConfig.queue(rabbitmqBeenCode.getName(), rabbitAdmin);
            registerSingleton(listableBeanFactory,
                    rabbitmqBeenCode.getModelName() + RabbitmqConfig.QUEUE,
                    queue);

            //创建绑定
            Binding binding = BindingBuilder.bind(queue).to(exchange).with(rabbitmqBeenCode.getName());
            binding.setAdminsThatShouldDeclare(rabbitAdmin);
            registerSingleton(listableBeanFactory,
                    rabbitmqBeenCode.getModelName() + RabbitmqConfig.BINDING,
                    binding);

            rabbitAdmin.declareExchange(exchange);
            rabbitAdmin.declareQueue(queue);
            rabbitAdmin.declareBinding(binding);
        }
    }

    public void registerSingleton(DefaultListableBeanFactory listableBeanFactory,String name,Object been){
        listableBeanFactory.registerSingleton(name,been);
    }
}
