package com.usky.dxtop.service.impl;


import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.mapper.DeptMapper;
import com.usky.dxtop.model.Dept;
import com.usky.dxtop.model.MsgLog;
import com.usky.dxtop.service.DeptService;
import com.usky.dxtop.service.MsgLogService;
import com.usky.dxtop.service.config.rabbitmq.RabbitmqUtils;
import com.usky.dxtop.service.constant.MsgLogBusinessCode;
import com.usky.dxtop.service.emun.RabbitmqBeenCode;
import com.usky.dxtop.service.vo.StaffRequest;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author yq
 * @since 2021-09-28
 */
@Service
public class DeptServiceImpl extends ServiceImpl<DeptMapper, Dept> implements DeptService {

    @Autowired
    private MsgLogService msgLogService;

    @Override
    public CommonPage<Dept> page(StaffRequest staffRequest) {
        IPage<Dept> page = new Page<>(staffRequest.getCurrent(), staffRequest.getSize());
        LambdaQueryWrapper<Dept> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(StringUtils.isNotBlank(staffRequest.getName()),Dept::getName,staffRequest.getName())
                .between(null != staffRequest.getStartTime() && null != staffRequest.getEndTime(),Dept::getCreateTime,
                        staffRequest.getStartTime(),staffRequest.getEndTime());
        page = this.page(page,queryWrapper);
        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getCurrent(),page.getSize());
    }

    @Override
    public List<Dept> list(StaffRequest staffRequest) {
        LambdaQueryWrapper<Dept> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper
                .select(Dept::getId,Dept::getDId,Dept::getPid,Dept::getName,Dept::getCreateTime,Dept::getCreateBy)
                .eq(StringUtils.isNotBlank(staffRequest.getName()),Dept::getName,staffRequest.getName())
                .between(null != staffRequest.getStartTime() && null != staffRequest.getEndTime(),Dept::getCreateTime,
                        staffRequest.getStartTime(),staffRequest.getEndTime());
        return this.list(queryWrapper);
    }

    @Override
    public List<Dept> buildDeptTree(List<Dept> depts) {
        List<Dept> returnList = new ArrayList<>();
        List<String> tempList = depts.stream().map(Dept::getId).collect(Collectors.toList());
        for (Dept dept:depts) {
            try {
                // 如果是顶级节点, 遍历该父节点的所有子节点
                if (!tempList.contains(dept.getPid()))
                {
                    deptSendMessage(dept,depts);
                    recursionFn(depts, dept);
                    returnList.add(dept);
                }
            }catch (Exception e){
                log.error("同步部门异常:"+e.getMessage());
            }
        }
        if (returnList.isEmpty())
        {
            returnList = depts;
        }
        return returnList;
    }

    @Override
    public List<Long> getChildListByDept(List<Dept> list, Dept t,List<Long> deptIds) {
        List<Dept> childList = getChildList(list, t);
        for (Dept tChild : childList) {
            deptIds.add(tChild.getDId());
            if (hasChild(list, tChild)) {
                getChildListByDept(list, tChild,deptIds);
            }
        }
        return deptIds;
    }

    /**
     * 递归列表
     */
    private void recursionFn(List<Dept> list, Dept t) {
        // 得到子节点列表
        List<Dept> childList = getChildList(list, t);
        t.setChildren(childList);
        for (Dept tChild : childList) {
            deptSendMessage(tChild,list);
            if (hasChild(list, tChild)) {
                recursionFn(list, tChild);
            }
        }
    }





    /**
     * 得到子节点列表
     */
    private List<Dept> getChildList(List<Dept> list, Dept t)
    {
        return list.stream().filter(dept -> dept.getPid().equals(t.getId())).collect(Collectors.toList());

    }

    /**
     * 判断是否有子节点
     */
    private boolean hasChild(List<Dept> list, Dept t)
    {
        return getChildList(list, t).size() > 0 ? true : false;
    }



    /**
     * 部门消息
     * @param dept
     */
    public void deptSendMessage(Dept dept,List<Dept> list){
        Map<String,Object> map = new HashMap<>();
        //获取父id
        Long pid = list.stream().filter(d -> d.getId().equals(dept.getPid())).map(Dept::getDId).findAny().orElse(0L);
        map.put("parentid",pid);
        map.put("id",dept.getDId());
        map.put("name",dept.getName());
        MsgLog msgLog = new MsgLog();
        msgLog.setBusinessId(String.format("%s%s", MsgLogBusinessCode.DEPT,dept.getDId()));
        msgLog.setExchange(RabbitmqBeenCode.PROFILE_DEPT_CONSUMER.getName());
        msgLog.setRoutingKey(RabbitmqBeenCode.PROFILE_DEPT_CONSUMER.getName());
        msgLog.setMsg(JSON.toJSONString(map));
        msgLogService.addOrUpdate(msgLog);
        map.put("seq",msgLog.getId());
        CorrelationData correlationData = new CorrelationData(msgLog.getId().toString());
        RabbitmqUtils.getRabbitmqTemplate(RabbitmqBeenCode.PROFILE_DEPT_CONSUMER).convertAndSend(msgLog.getExchange(), msgLog.getRoutingKey(), map,correlationData);
    }
}
