package com.usky.dxtop.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.usky.dxtop.mapper.MsgLogMapper;
import com.usky.dxtop.model.MsgLog;
import com.usky.dxtop.service.MsgLogService;
import com.usky.dxtop.service.emun.MsgLogStatus;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.function.Consumer;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author yq
 * @since 2021-10-13
 */
@Slf4j
@Service
public class MsgLogServiceImpl extends ServiceImpl<MsgLogMapper, MsgLog> implements MsgLogService {

    @Override
    public Boolean isRepetition(MsgLog msgLog) {
        return !(null == msgLog || msgLog.getMsgFlag().equals(MsgLogStatus.CONSUMER_SUCCESS.getCode()));
    }

    @Override
    public void consumerSuccess(String consequence, Consumer<MsgLog> consumer) {
        JSONObject jsonObject = JSONObject.parseObject(consequence);
        Long msgId = Long.parseLong(jsonObject.get("seq").toString());
        MsgLog msgLog = this.getById(msgId);
        if (this.isRepetition(msgLog)){
            boolean isSuccess = "1".equals(jsonObject.get("code").toString());
            msgLog.setIsSuccess(isSuccess);
            msgLog.setUpdateTime(new Date());
            msgLog.setConsequence(consequence);
            msgLog.setMsgFlag(MsgLogStatus.CONSUMER_SUCCESS.getCode());
            this.updateById(msgLog);
            consumer.accept(msgLog);
        }
    }

    @Override
    public void addOrUpdate(MsgLog msgLog) {
        msgLog.setId(System.currentTimeMillis());
        msgLog.setCreateTime(new Date());
        LambdaUpdateWrapper<MsgLog> updateWrapper = Wrappers.lambdaUpdate();
        updateWrapper.set(MsgLog::getId,msgLog.getId());
        updateWrapper.eq(MsgLog::getBusinessId,msgLog.getBusinessId());
        this.saveOrUpdate(msgLog,updateWrapper);

    }

}
