package com.usky.dxtop.service.impl;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.usky.dxtop.common.constant.UserConstants;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.SecurityUtils;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.mapper.QrCodeMapper;
import com.usky.dxtop.model.QrCode;
import com.usky.dxtop.model.TopChannel;
import com.usky.dxtop.service.ISysConfigService;
import com.usky.dxtop.service.QrCodeService;
import com.usky.dxtop.service.TopChannelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Optional;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author yq
 * @since 2021-08-26
 */
@Service
public class QrCodeServiceImpl extends ServiceImpl<QrCodeMapper, QrCode> implements QrCodeService {

    @Autowired
    private ISysConfigService sysConfigService;

    @Autowired
    private TopChannelService topChannelService;


    @Override
    public boolean add(QrCode qrCode) {
        Optional.ofNullable(qrCode.getTopChannelId())
                .filter(cId -> 0L != cId)
                .orElseThrow(() ->new CustomException("渠道编号不能为空"));
        TopChannel topChannel = topChannelService.getById(qrCode.getTopChannelId());
        Optional.ofNullable(topChannel)
                .orElseThrow(() ->new CustomException("渠道不能为空"));
        qrCode.setCreateBy(SecurityUtils.getUsername());
        return this.save(qrCode);
    }

    @Override
    public String checkNameUnique(QrCode qrCode) {
        Long configId = StringUtils.isNull(qrCode.getId()) ? -1L : qrCode.getId();
        LambdaQueryWrapper<QrCode> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(QrCode::getName,qrCode.getName())
                .eq(QrCode::isDelFlag,0);
        QrCode one = this.getOne(queryWrapper);
        if (StringUtils.isNotNull(one) && one.getId() != configId.longValue())
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    @Override
    public CommonPage<QrCode> list(Integer current,Integer size,String name) {
        String payPath = sysConfigService.selectConfigByKey("app.pay.path");
        IPage<QrCode> page = new Page<>(current, size);
        page = baseMapper.list(page,name);
        page.getRecords().forEach(qrCode -> qrCode.setQrPath(String.format("%s?type=%s&channelName=%s", payPath, qrCode.getTopChannelId(),qrCode.getTopChannelName())));
        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getCurrent(),page.getSize());
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean remove(Long id) {
        QrCode qrCode = new QrCode();
        qrCode.setId(id);
        qrCode.setDelFlag(true);
        return this.updateById(qrCode);
    }
}
