package com.usky.dxtop.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.mapper.StaffRadioMapper;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.model.StaffRadio;
import com.usky.dxtop.service.DeptService;
import com.usky.dxtop.service.StaffRadioService;
import com.usky.dxtop.service.StaffService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author yq
 * @since 2021-09-23
 */
@Service
public class StaffRadioServiceImpl extends ServiceImpl<StaffRadioMapper, StaffRadio> implements StaffRadioService {

    @Autowired
    private StaffService staffService;

    @Autowired
    private DeptService deptService;

    @Override
    public void addList(List<StaffRadio> list) {
        if (CollectionUtils.isEmpty(list)){
            throw new CustomException("请选择要关联的信息");
        }
        List<StaffRadio> removeList = list.stream()
                .filter(staffRadio -> null != staffRadio.getRadioId() && 0 != staffRadio.getRadioId())
                .filter(staffRadio -> !staffRadio.isDelFlag()).collect(Collectors.toList());

        List<StaffRadio> addList = list.stream()
                .filter(staffRadio -> null != staffRadio.getRadioId() && 0 != staffRadio.getRadioId())
                .filter(StaffRadio::isDelFlag).collect(Collectors.toList());
        if (CollectionUtils.isNotEmpty(removeList)){
            LambdaQueryWrapper<StaffRadio> queryWrapper = Wrappers.lambdaQuery();
            queryWrapper.in(StaffRadio::getStaffId,removeList.stream().map(StaffRadio::getStaffId).collect(Collectors.toList()));
            this.remove(queryWrapper);
        }
        if (CollectionUtils.isNotEmpty(addList)){
            this.saveBatch(addList);
        }


    }

    @Override
    public boolean addListByDept(List<Long> deptIds, Boolean isBinding,Long radioId) {
        LambdaQueryWrapper<Staff> staffLambdaQueryWrapper = Wrappers.lambdaQuery();
        staffLambdaQueryWrapper.select(Staff::getSId)
                .in(Staff::getDeptId,deptIds);
        List<Long> list = staffService.list(staffLambdaQueryWrapper).stream().map(Staff::getSId).collect(Collectors.toList());
        if (CollectionUtils.isNotEmpty(list)){
            LambdaQueryWrapper<StaffRadio> queryWrapper = Wrappers.lambdaQuery();
            queryWrapper.in(StaffRadio::getStaffId,list);
            this.remove(queryWrapper);
            if (isBinding){
                List<StaffRadio> addList = list.stream().map(staff -> {
                    StaffRadio staffRadio = new StaffRadio();
                    staffRadio.setRadioId(radioId);
                    staffRadio.setStaffId(staff);
                    return staffRadio;
                }).collect(Collectors.toList());
                this.saveBatch(addList);
            }
        }
        return true;
    }

    @Override
    public List<Map<String,Object>> staffRadio() {
        return baseMapper.staffRadio();
    }
}
