package com.usky.dxtop.service.impl;


import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.common.utils.file.ImageUtils;
import com.usky.dxtop.common.utils.sign.Base64;
import com.usky.dxtop.mapper.StaffMapper;
import com.usky.dxtop.model.MsgLog;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.service.MsgLogService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.config.rabbitmq.RabbitmqUtils;
import com.usky.dxtop.service.constant.MsgLogBusinessCode;
import com.usky.dxtop.service.emun.RabbitmqBeenCode;
import com.usky.dxtop.service.vo.StaffRequest;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author yq
 * @since 2021-09-28
 */
@Service
public class StaffServiceImpl extends ServiceImpl<StaffMapper, Staff> implements StaffService {

    @Autowired
    private MsgLogService msgLogService;


    @Override
    public CommonPage<Staff> page(StaffRequest staffRequest) {
        IPage<Staff> page = new Page<>(staffRequest.getCurrent(), staffRequest.getSize());
        page = baseMapper.page(page, staffRequest.getStartTime(),
                staffRequest.getEndTime(),
                staffRequest.getName(),
                staffRequest.getPhone(),
                staffRequest.getCard(),
                staffRequest.getDeptId());
        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getCurrent(),page.getSize());
    }

    @Override
    public BigDecimal getBalance(String card) {
        Staff staff = this.one(null, null, card);
        Optional.ofNullable(staff).orElseThrow(() -> new CustomException("用户信息不存在"));
        return Optional.ofNullable(staff.getBalance()).orElse(new BigDecimal("0.00"));
    }

    @Override
    public Staff one(String id, String phone, String card) {
        if (StringUtils.isBlank(id) && StringUtils.isBlank(phone) && StringUtils.isBlank(card)){
            throw new CustomException("手机号，用户编号，卡号至少输入一个");
        }
        return baseMapper.one(id,phone,card);
    }


    /**
     * 人员消息
     * @param staff
     */
    @Override
    public void personSendMessage(Staff staff,Integer type){
        Map<String,Object> map = new HashMap<>();
        map.put("type",type);
        map.put("card_type",1);
        map.put("card",staff.getCardId());
        map.put("name",staff.getName());
        map.put("mob",staff.getSId());
        map.put("groupid",staff.getDeptId());
        map.put("tel",staff.getContacts());
        map.put("level_name","员工卡");
        MsgLog msgLog = new MsgLog();
        msgLog.setBusinessId(String.format("%s%s", MsgLogBusinessCode.STAFF,staff.getSId()));
        msgLog.setExchange(RabbitmqBeenCode.PROFILE_CONSUMER.getName());
        msgLog.setRoutingKey(RabbitmqBeenCode.PROFILE_CONSUMER.getName());
        msgLog.setMsg(JSON.toJSONString(map));
        msgLogService.addOrUpdate(msgLog);
        map.put("seq",msgLog.getId());
        CorrelationData correlationData = new CorrelationData(msgLog.getId().toString());
        RabbitmqUtils.getRabbitmqTemplate(RabbitmqBeenCode.PROFILE_CONSUMER).convertAndSend(msgLog.getExchange(), msgLog.getRoutingKey(), map,correlationData);
    }


    /**
     * 人脸
     * @param staff
     */
    @Override
    public void faceSendMessage(Staff staff){
        String encode = Base64.encode(ImageUtils.getImage(staff.getFaceId()));
        Map<String,Object> map = new HashMap<>();
        map.put("mob",staff.getSId());
        MsgLog msgLog = new MsgLog();
        msgLog.setBusinessId(String.format("%s%s", MsgLogBusinessCode.FACE,staff.getSId()));
        msgLog.setExchange(RabbitmqBeenCode.PROFILE_FACE_CONSUMER.getName());
        msgLog.setRoutingKey(RabbitmqBeenCode.PROFILE_FACE_CONSUMER.getName());
        map.put("img",staff.getFaceId());
        msgLog.setMsg(JSON.toJSONString(map));
        msgLogService.addOrUpdate(msgLog);
        map.put("seq",msgLog.getId());
        map.put("img",encode);
        CorrelationData correlationData = new CorrelationData(msgLog.getId().toString());
        RabbitmqUtils.getRabbitmqTemplate(RabbitmqBeenCode.PROFILE_FACE_CONSUMER).convertAndSend(msgLog.getExchange(), msgLog.getRoutingKey(), map,correlationData);
    }

    @Override
    public List<Staff> selectStaffByPhoneList(List<String> phoneList) {
        return baseMapper.selectListByPhones(phoneList);
    }
}
