package com.usky.dxtop.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.usky.dxtop.common.constant.UserConstants;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.mapper.TopChannelMapper;
import com.usky.dxtop.model.QrCode;
import com.usky.dxtop.model.TopChannel;
import com.usky.dxtop.service.QrCodeService;
import com.usky.dxtop.service.TopChannelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 充值渠道 服务实现类
 * </p>
 *
 * @author yq
 * @since 2021-08-26
 */
@Service
public class TopChannelServiceImpl extends ServiceImpl<TopChannelMapper, TopChannel> implements TopChannelService {
    @Autowired
    private QrCodeService qrCodeService;

    @Override
    public String checkNameUnique(TopChannel topChannel) {
        Long configId = StringUtils.isNull(topChannel.getId()) ? -1L : topChannel.getId();
        LambdaQueryWrapper<TopChannel> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(TopChannel::getName,topChannel.getName())
                .eq(TopChannel::isDelFlag,0);
        TopChannel one = this.getOne(queryWrapper);
        if (StringUtils.isNotNull(one) && one.getId() != configId.longValue())
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    @Override
    public CommonPage<TopChannel> list(Integer current,Integer size,String name) {
        IPage<TopChannel> page = new Page<>(current, size);
        LambdaQueryWrapper<TopChannel> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.like(StringUtils.isNotBlank(name),TopChannel::getName,name)
                .eq(TopChannel::isDelFlag,false)
                .orderByDesc(TopChannel::getId);
        page = this.page(page, queryWrapper);
        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getCurrent(),page.getSize());
    }

    @Override
    public boolean remove(Long id) {
        LambdaQueryWrapper<QrCode> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(QrCode::getTopChannelId,id)
                    .eq(QrCode::isDelFlag,false);
        int count = qrCodeService.count(queryWrapper);
        if (count > 0){
            throw new CustomException("渠道已经关联二维码不能删除");
        }
        TopChannel topChannel = new TopChannel();
        topChannel.setId(id);
        topChannel.setDelFlag(true);
        return this.updateById(topChannel);
    }

    @Override
    public List<Map<String, Object>> channelOrderMoney() {
        return baseMapper.channelOrderMoney();
    }
}
