package com.usky.dxtop.service.job;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.dxtop.model.Charge;
import com.usky.dxtop.model.MsgLog;
import com.usky.dxtop.model.Order;
import com.usky.dxtop.service.ChargeService;
import com.usky.dxtop.service.MsgLogService;
import com.usky.dxtop.service.OrderService;
import com.usky.dxtop.service.emun.OrderStatus;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.TreeMap;

/**
 * @author yq
 * @date 2021/9/16 9:31
 */
@Slf4j
@Component("cardJob")
public class CardJob {

    private TreeMap<String,Integer> treeMap = new TreeMap<>();

    @Autowired
    private OrderService orderService;
    @Autowired
    private ChargeService chargeService;
    @Autowired
    private MsgLogService msgLogService;

    public void execute(String param){
        for (Order order:getData(param)) {
            try {
                LambdaQueryWrapper<MsgLog> msgLogLambdaQueryWrapper = Wrappers.lambdaQuery();
                msgLogLambdaQueryWrapper.eq(MsgLog::getBusinessId,order.getId());
                List<MsgLog> msgLogs = msgLogService.list(msgLogLambdaQueryWrapper);
                if (CollectionUtils.isNotEmpty(msgLogs)){
                    Charge one = chargeService.one(msgLogs.get(0).getId());
                    if (null == one){
                        cartError(order);
                    }else {
                        order.setOrderFlag(OrderStatus.COMPLETE.getCode());
                        orderService.updateById(order);
                    }
                }
            }catch (Exception e){
                log.error("---orderJob---异常"+e.getMessage());
            }
        }
        log.info("---orderJob---处理完成");
    }

    public List<Order> getData(String param){
        CardJobParam cardJobParam = JSON.parseObject(param, CardJobParam.class);
        LambdaQueryWrapper<Order> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper
                .eq(StringUtils.isNotBlank(cardJobParam.getOrderNumber()),Order::getOrderNumber,cardJobParam.getOrderNumber())
                .eq(Order::getOrderFlag,OrderStatus.SUCCESS.getCode());
        return orderService.list(queryWrapper);
    }

    public void cartError(Order order){
        String orderNumber = order.getOrderNumber();
        if (treeMap.containsKey(orderNumber)){
            Integer count = treeMap.get(orderNumber);
            if (count >= 10){
                order.setOrderFlag(OrderStatus.PAYMENT_ERROR_DEBIT.getCode());
                orderService.updateById(order);
            }else {
                treeMap.put(orderNumber,count+1);
            }
        }else {
            treeMap.put(orderNumber,1);
        }
    }


    @Data
    public static class CardJobParam {
        private String orderNumber;
    }
}
