package com.usky.dxtop.service.job;


import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.dxtop.common.utils.SecurityUtils;
import com.usky.dxtop.common.utils.StringUtils;

import com.usky.dxtop.model.Dept;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.model.SysDept;
import com.usky.dxtop.model.SysUser;
import com.usky.dxtop.service.ISysDeptService;
import com.usky.dxtop.service.ISysUserService;
import com.usky.dxtop.service.api.SmApi;
import com.usky.dxtop.service.util.CenterDecryptUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

@Component("centerUserJob")
@Slf4j
public class CenterUserJob {

    @Autowired
    private ISysUserService iSysUserService;

    @Autowired
    private ISysDeptService iSysDeptService;

    @Autowired
    private SmJob smJob;


    public void personExecute(String param) {
        SmJob.PersonParam personParam = JSON.parseObject(param, SmJob.PersonParam.class);
        personApi(personParam);
        log.info("smJob-person 定时任务完成");
    }

    public void groupExecute(String param) {
        SmJob.GroupParam groupParam = JSON.parseObject(param, SmJob.GroupParam.class);
        groupApi(groupParam);
        log.info("smJob-group 定时任务完成");
    }

    public void  personApi(SmJob.PersonParam personParam){
        TreeMap<String, Object> treeMap;
        if (null != personParam){
            treeMap = SmApi.generatePersonParam(personParam.getId(),
                    personParam.getDeptIds(), personParam.getCreateTime(), personParam.getBlurry());
        }else {
            treeMap = SmApi.generatePersonParam(null,
                    null, null, null);
        }
        List<SysDept> depts = iSysDeptService.list();
        smJob.common(SmApi.PERSON_URL,treeMap,staffList -> {
            List<Staff> list = staffList.toJavaList(Staff.class);
            list.forEach(date -> {
                try {
                    //只负责同步
                    LambdaQueryWrapper<SysUser> queryWrapper = Wrappers.lambdaQuery();
                    queryWrapper.eq(SysUser::getCenterUserId,date.getId());
                    iSysUserService.saveOrUpdate(generateSysUser(date,depts),queryWrapper);
                }catch (Exception e){
                    log.error("smJob-person:"+e.getMessage());
                }
            });
            return list.isEmpty();
        });
    }

    public void groupApi(SmJob.GroupParam groupParam){
        TreeMap<String, Object> treeMap;
        if (null != groupParam){
            treeMap = SmApi.generateDeptParam(groupParam.getCreateTime(),
                    groupParam.getName(),groupParam.getPid(),groupParam.getEnable());
        }else {
            treeMap = SmApi.generateDeptParam(null,
                    null,null,null);
        }
        smJob.common(SmApi.DEPT_URL,treeMap,deptList -> {
            List<Dept> list = deptList.toJavaList(Dept.class);
            list.forEach(date -> {
                try {
                    //只负责同步
                    LambdaQueryWrapper<SysDept> queryWrapper = Wrappers.lambdaQuery();
                    queryWrapper.eq(SysDept::getCenterDeptId,date.getId());
                    if (StringUtils.isBlank(date.getPid())){
                        date.setPid("0");
                    }
                    iSysDeptService.saveOrUpdate(generateSysDept(date),queryWrapper);
                }catch (Exception e){
                    log.error("smJob-group:"+e.getMessage());
                }
            });
            return list.isEmpty();
        });
        //寻找各部门的父id
        iSysDeptService.setDeptTree(iSysDeptService.list());
    }

    public SysDept generateSysDept(Dept dept){
        SysDept sysDept = new SysDept();
        sysDept.setDeptName(dept.getName());
        sysDept.setCenterDeptId(dept.getId());
        sysDept.setOrderNum(dept.getDeptSort().toString());
        sysDept.setCenterParentId(dept.getPid());
        return sysDept;
    }

    public SysUser generateSysUser(Staff staff,List<SysDept> depts){
        SysUser sysUser = new SysUser();
        sysUser.setCreateTime(new Date());
        sysUser.setCenterUserId(staff.getId());
        sysUser.setUserName(staff.getUsername());
        String pwd = "";
        try {
            pwd = CenterDecryptUtil.decryptByPrivateKey(CenterDecryptUtil.KEY,staff.getOsspassword());
        }catch (Exception e){

        }
        sysUser.setPassword(SecurityUtils.encryptPassword(pwd));
        sysUser.setPhonenumber(staff.getContacts());
        sysUser.setEmail(staff.getEmail());
        if (null != staff.getSex()){
            if ("男".equals(staff.getSex())){
                sysUser.setSex("0");
            }else if ("女".equals(staff.getSex())){
                sysUser.setSex("1");
            }else {
                sysUser.setSex("2");
            }
        }
        sysUser.setNickName(staff.getName());

        //获取部门信息
        Map deptMap = JSON.parseObject(staff.getDept(), Map.class);
        SysDept sysDept = depts.stream().filter(dept -> dept.getCenterDeptId().equals(deptMap.get("id").toString())).findAny().get();
        sysUser.setDeptId(sysDept.getDeptId());
        return sysUser;
    }
}
