package com.usky.dxtop.service.job;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.dxtop.model.SysFile;
import com.usky.dxtop.service.SysFileService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.Date;
import java.util.List;

/**
 * @author yq
 * @date 2021/10/9 13:34
 */
@Component("fileJob")
@Slf4j
public class FileJob {
    @Autowired
    private SysFileService fileService;

    public void execute(String param) {
        List<SysFile> sysFileList = getData(param);
        if (CollectionUtils.isEmpty(sysFileList)) {
            return;
        }
        Integer integer = fileService.clearFiles(sysFileList);
        log.info("删除的file条数=:" + integer);
    }

    public List<SysFile> getData(String param){
        FileJobParam fileJobParam = JSON.parseObject(param, FileJobParam.class);
        LambdaQueryWrapper<SysFile> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(SysFile::getDelFlag, 0)
                .eq(StringUtils.isNotBlank(fileJobParam.getBatchNo()),SysFile::getBatchNo,fileJobParam.getBatchNo())
                .and(wrapper -> wrapper.eq(SysFile::getActiveFlag, 0)
                        .or()
                        .eq(SysFile::getActiveFlag, 1))
                .isNotNull(SysFile::getExpriceAt)
                .le(SysFile::getExpriceAt,new Date());
        return fileService.list(queryWrapper);
    }

    @Data
    public static class FileJobParam {
        private String batchNo;
    }
}
