package com.usky.dxtop.service.job;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.dxtop.model.Order;
import com.usky.dxtop.service.OrderService;
import com.usky.dxtop.service.emun.OrderPayType;
import com.usky.dxtop.service.emun.OrderStatus;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @author yq
 * @date 2021/8/30 16:57
 */
@Slf4j
@Component("orderJob")
public class OrderJob {
    @Autowired
    private OrderService orderService;

    public void execute(String param){
        for (Order order:getData(param)) {
            try {
                orderService.callTopFindOrderInfoApi(order.getOrderNumber());
            }catch (Exception e){
                log.error("---orderJob---异常"+"订单编号:"+order.getOrderNumber()+":"+e.getMessage());
            }
        }
    }

    public List<Order> getData(String param){
        OrderJobParam orderJobParam = JSON.parseObject(param, OrderJobParam.class);
        LambdaQueryWrapper<Order> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper
                .eq(StringUtils.isNotBlank(orderJobParam.getOrderNumber()),Order::getOrderNumber,orderJobParam.getOrderNumber())
                .ne(Order::getPayType, OrderPayType.XJ.getPayCode())
                .and(wrapper -> wrapper.eq(Order::getOrderFlag, OrderStatus.NO_PAYMENT.getCode())
                        .or()
                        .eq(Order::getOrderFlag, OrderStatus.AWAIT_PAY.getCode()));
        return orderService.list(queryWrapper);
    }


    @Data
    public static class OrderJobParam {
        private String orderNumber;
    }
}
