package com.usky.dxtop.service.listener;

import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.model.Order;
import com.usky.dxtop.service.MsgLogService;
import com.usky.dxtop.service.OrderService;
import com.usky.dxtop.service.config.rabbitmq.RabbitmqFactoryAware;
import com.usky.dxtop.service.constant.MsgLogBusinessCode;
import com.usky.dxtop.service.emun.OrderStatus;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.amqp.rabbit.listener.RabbitListenerContainerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.nio.charset.StandardCharsets;

/**
 * @author yq
 * @date 2021/9/15 13:56
 */
@Slf4j
@Component
public class ChargeMqListener {

    private final static String QUEUE_NAME = "card_charge_produce";

    private final static String LISTENER_NAME = "chargePListenerFactory";

    @Autowired
    private OrderService orderService;
    @Autowired
    private MsgLogService msgLogService;
    @Autowired
    private RabbitmqFactoryAware rabbitmqFactoryAware;

    @Transactional(rollbackFor = Exception.class)
    @RabbitListener(queues = QUEUE_NAME, containerFactory = LISTENER_NAME)
    public void dealDeclareMessage(Message message) {
        try {
            String s = new String(message.getBody(), StandardCharsets.UTF_8);
            msgLogService.consumerSuccess(s,msgLog -> {
                Order order = new Order();
                String orderId = StringUtils.remove(msgLog.getBusinessId(), MsgLogBusinessCode.ORDER);
                order.setId(Long.parseLong(orderId));
                if (msgLog.getIsSuccess()){
                    order.setOrderFlag(OrderStatus.COMPLETE.getCode());
                }else {
                    order.setOrderFlag(OrderStatus.PAYMENT_ERROR_DEBIT.getCode());
                }
                orderService.updateById(order);
            });
        } catch (Exception e) {
            log.info("charge_trans_produce"+"异常信息：" + e.getMessage());
            throw new CustomException(e.getMessage());
        }
    }
}
