package com.usky.dxtop.service.listener;

import com.alibaba.fastjson.JSONObject;
import com.usky.dxtop.common.utils.Arith;
import com.usky.dxtop.common.utils.DateUtils;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.model.Charge;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.service.ChargeService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.api.WxApi;
import com.usky.dxtop.service.config.rabbitmq.ChargeTransConfig;
import com.usky.dxtop.service.config.rabbitmq.RabbitmqFactoryAware;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;

/**
 * @author yq
 * @date 2021/9/9 11:05
 */
@Slf4j
@Component
public class ChargeTransMqListener {


    private static final String URL = "https://smartpark.caih.com/vuepay/#/record?id=1";

    @Autowired
    private ChargeService chargeService;

    @Autowired
    private StaffService staffService;

    @Autowired
    private WxApi wxApi;

    @Autowired
    private RabbitmqFactoryAware rabbitmqFactoryAware;
    @RabbitListener(queues = ChargeTransConfig.NAME, containerFactory = ChargeTransConfig.LISTENER)
    public void dealDeclareMessage(Message message) {
        try {
            //消息类型
            String routingKey = message.getMessageProperties().getReceivedRoutingKey();
            log.info(routingKey);
            String s = new String(message.getBody(), StandardCharsets.UTF_8);
            log.info("charge_trans_produce:接受到的消息"+s);
            Charge charge = JSONObject.parseObject(s, Charge.class);
            chargeService.saveOrUpdate(charge);
            //更新用户余额
            Staff staff = staffService.one(null, null, charge.getCard());
            staff.setBalance(charge.getBalance());
            staffService.updateById(staff);
            if (StringUtils.isNotBlank(staff.getOpenId())){
                String  result = wxApi.sendMessageApi(staff.getOpenId(),getMessageData(charge),wxApi.getToken(WxApi.APP_ID,WxApi.SECRET),WxApi.CHARGE_TEMPLATE_ID,URL);
                wxApi.againSendMessage(result,staff.getOpenId(), getMessageData(charge), WxApi.CHARGE_TEMPLATE_ID, URL,WxApi.APP_ID,WxApi.SECRET);
            }
        } catch (Exception e) {
            log.info("charge_trans_produce"+"异常信息：" + e.getMessage());
        } finally {

        }
    }


    public Map<String,Object> getMessageData(Charge charge){
        Map<String, Object> map = new HashMap<>();
        map.put("first",getMap("恭喜您，充值成功，以下为相关简讯",null));
        map.put("keyword1",getMap("余额充值",null));
        map.put("keyword2",getMap(String.format("%s%s", Arith.div(charge.getAmt().doubleValue(),1,2)," 元"),null));
        map.put("keyword3",getMap(DateUtils.format(charge.getCreateTime(),null),null));
        map.put("remark",getMap("如有疑问，请及时在线联系我们的客服！",null));
        return map;
    }

    public Map<String,Object> getMap(Object value,String color){
        Map<String,Object> map = new HashMap<>();
        map.put("value",value);
        map.put("color",color);
        return map;
    }
}
