package com.usky.dxtop.service.listener;

import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.model.Dept;
import com.usky.dxtop.service.DeptService;
import com.usky.dxtop.service.MsgLogService;
import com.usky.dxtop.service.config.rabbitmq.RabbitmqFactoryAware;
import com.usky.dxtop.service.constant.MsgLogBusinessCode;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.nio.charset.StandardCharsets;

/**
 * @author yq
 * @date 2021/9/15 13:56
 */
@Slf4j
@Component
public class GroupMqListener {
    private final static String QUEUE_NAME = "group_produce";

    private final static String LISTENER_NAME = "groupPListenerFactory";

    @Autowired
    private MsgLogService msgLogService;
    @Autowired
    private DeptService deptService;
    @Autowired
    private RabbitmqFactoryAware rabbitmqFactoryAware;
    @RabbitListener(queues = QUEUE_NAME, containerFactory = LISTENER_NAME)
    public void dealDeclareMessage(Message message) {
        try {
            String s = new String(message.getBody(), StandardCharsets.UTF_8);
            msgLogService.consumerSuccess(s,msgLog -> {
                String deptId = StringUtils.remove(msgLog.getBusinessId(), MsgLogBusinessCode.DEPT);
                Dept dept = deptService.getById(deptId);
                if (null != dept && !dept.getIsSuccess()){
                    dept.setIsSuccess(msgLog.getIsSuccess());
                    deptService.updateById(dept);
                }
            });
        } catch (Exception e) {
            log.info("charge_trans_produce"+"异常信息：" + e.getMessage());
        } finally {

        }
    }
}
